# Algolia Resource Provider

The Algolia Resource Provider lets you manage [Algolia](https://algolia.com) resources.

## Installing

This package is available for python only.

### Python

To use from Python, install using `pip`:

```bash
pip install sw_pulumi_algolia
```

## Configuration

The following configuration points are available for the `foo` provider:

- `algolia:apiKey` - (Required) the admin API key from your algolia account.
- `algolia:applicationId` - (Required) the application ID from your algolia account.

## Reference

For detailed reference documentation, please visit [Pulumi Algolia Repo](https://github.com/swarm-work/pulumi-algolia).
API docs in Pulumi Registry is on its way.
